@@ -1,7 +1,7 @@
 /*
  * frogr-controller.c -- Controller of the whole application
  *
- * Copyright (C) 2009-2016 Mario Sanchez Prada
+ * Copyright (C) 2009-2018 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -693,7 +693,7 @@ _show_auth_failed_dialog (GtkWindow *parent, const gchar *message, gboolean auto
                     G_CALLBACK (_auth_failed_dialog_response_cb),
                     GINT_TO_POINTER ((gint)auto_retry));
 
-  gtk_widget_show_all (dialog);
+  gtk_widget_show (dialog);
 }
 
 static void
